Welcome to django-simple-menu's documentation!
==============================================

django-simple-menu allows you to define multiple menus using straight forward
python code in each of your installed apps.

The menus you define can be simple & straight forward with a static title and
url or they can change based on the current request to support dynamic titles
or complex permissions.

Contents:

.. toctree::
   :maxdepth: 2

   installation.rst
   configuration.rst
   usage.rst
   example.rst
